==> modx-2.1.5-pl-ja.zip: modx-2.1.5-pl-ja/core/lexicon/ja/topmenu.inc.php <==
<?php
/**
 * Top Menu Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['about'] = 'MODXについて';
$_lang['about_desc'] = 'MODX Revolutionに関する情報';
$_lang['access_permissions'] = 'アクセス許可';
$_lang['access_permissions_desc'] = 'リソースとコンテキストへのユーザーアクセス管理';
$_lang['api_docs'] = 'APIドキュメント';
$_lang['api_docs_desc'] = 'Complete API documentation for MODX Revolution.';
$_lang['components'] = 'コンポーネント';
$_lang['content_types'] = 'コンテンツタイプ';
$_lang['content_types_desc'] = 'リソースのコンテンツタイプを管理。フレンドリーURL設定時に付加される拡張子もここで設定';
$_lang['contexts'] = 'コンテキスト';
$_lang['contexts_desc'] = 'サイトのコンテキストを管理';
$_lang['dashboard'] = 'ダッシュボード';
$_lang['dashboards'] = 'ダッシュボード';
$_lang['dashboards_desc'] = 'ダッシュボードの管理';
$_lang['edit_menu'] = 'アクション';
$_lang['edit_menu_desc'] = 'システム全体のアクションと管理画面トップメニュー構成の管理';
$_lang['eventlog_viewer'] = 'イベントログ';
$_lang['eventlog_viewer_desc'] = 'エラーログを表示';
$_lang['export_site'] = 'サイトのエクスポート';
$_lang['export_site_desc'] = '現在のウェブサイトを静的なhtmlへエクスポート';
$_lang['flush_access'] = 'アクセス許可をリロード';
$_lang['flush_access_confirm'] = '正しいアクセス許可設定を読み直しますか？注: これは他のユーザーへ影響を与えません';
$_lang['flush_access_desc'] = '一時的にキャッシュされている権限情報を初期化し正しく読み直す';
$_lang['flush_sessions'] = '全セッションを初期化';
$_lang['flush_sessions_confirm'] = '全ユーザーのセッション情報を初期化しますか？自分自身を含めた全ユーザーのセッション情報が初期化されます';
$_lang['flush_sessions_desc'] = '全セッションを初期化し全てのユーザーを強制ログアウト';
$_lang['flush_sessions_err'] = '現在のユーザーセッションを初期化中にエラーが発生しました';
$_lang['flush_sessions_not_supported'] = '現在のアカウントは、ユーザーセッションの初期化権限を持っていません';
$_lang['form_customization'] = '管理画面カスタマイズ機能';
$_lang['form_customization_desc'] = '管理画面のフォームをカスタマイズ。ロール単位で設定可能';
$_lang['forums'] = 'フォーラム';
$_lang['forums_desc'] = '公式MODXフォーラムへアクセス';
$_lang['import_resources'] = 'リソースのインポート';
$_lang['import_resources_desc'] = 'スタティックリソースの一括インポート';
$_lang['import_site'] = 'サイトのインポート';
$_lang['import_site_desc'] = 'HTMLファイルの一括インポート';
$_lang['jira'] = 'バグトラッカー';
$_lang['jira_desc'] = 'MODX バグトラッカーにアクセスし不具合や改善要望を報告';
$_lang['lexicon_management'] = 'レキシコン管理';
$_lang['lexicon_management_desc'] = 'レキシコン(辞書機能・従来の言語ファイルに相当)を管理';
$_lang['logout_desc'] = '管理画面からログアウト';
$_lang['manage_workspaces'] = 'パッケージマネージャー';
$_lang['manage_workspaces_desc'] = '拡張機能やテンプレートを入手・インストール・アンインストール。パッケージ単位で管理';
$_lang['messages'] = 'メッセージ';
$_lang['messages_desc'] = 'メッセージの閲覧と送信';
$_lang['namespaces'] = 'ネームスペース';
$_lang['namespaces_desc'] = 'ネームスペースの定義';
$_lang['new_document'] = 'ドキュメントを新規作成';
$_lang['new_document_desc'] = 'ドキュメントを新規作成';
$_lang['new_resource'] = '新しいリソース';
$_lang['new_resource_desc'] = 'リソースを新規作成';
$_lang['new_static_resource'] = 'スタティックリソースを新規作成';
$_lang['new_static_resource_desc'] = 'スタティックリソース(任意のファイルのクローン)を新規作成';
$_lang['new_symlink'] = 'シムリンクを新規作成';
$_lang['new_symlink_desc'] = 'シムリンク(任意のリソースのクローン)を新規作成';
$_lang['new_weblink'] = 'ウェブリンクを新規作成';
$_lang['new_weblink_desc'] = 'ウェブリンク(任意のURLのエイリアス)を新規作成';
$_lang['policy_management'] = 'アクセスポリシー';
$_lang['policy_management_desc'] = 'セキュリティプロセスのためのポリシー設定';
$_lang['preview'] = 'プレビュー';
$_lang['preview_desc'] = 'サイトを表示(別窓)';
$_lang['profile'] = 'プロフィール';
$_lang['profile_desc'] = '自分自身の個人プロフィールを編集';
$_lang['propertysets'] = 'プロパティセット';
$_lang['propertysets_desc'] = 'プロパティセットと、それらが配置されるエレメントのすべてを管理';
$_lang['refresh_site'] = 'キャッシュをクリア';
$_lang['refresh_site_desc'] = 'キャッシュを初期化。管理画面のレキシコン(言語管理)のキャッシュなども含む';
$_lang['remove_locks'] = 'ロックを解除';
$_lang['remove_locks_desc'] = 'サイト全体の編集ロックを解除';
$_lang['remove_locks_error'] = 'ロックの解除中にエラーが発生しました';
$_lang['reports'] = 'レポート';
$_lang['resource_groups'] = 'リソースグループ';
$_lang['resource_groups_desc'] = 'リソースグループを管理';
$_lang['search'] = '検索';
$_lang['search_desc'] = 'リソースの検索';
$_lang['security'] = '権限管理';
$_lang['site'] = 'サイト';
$_lang['sources'] = 'メディアソース';
$_lang['sources_desc'] = 'メディアソースの管理';
$_lang['support'] = 'サポート';
$_lang['support_desc'] = '';
$_lang['site_schedule'] = '公開状態の一覧';
$_lang['site_schedule_desc'] = '公開および公開終了の予定一覧';
$_lang['system'] = 'システム';
$_lang['system_settings'] = 'システム設定';
$_lang['system_settings_desc'] = 'サイト全体の設定変更';
$_lang['tools'] = 'ツール';
$_lang['user'] = 'ユーザー';
$_lang['user_management'] = 'ユーザー管理';
$_lang['user_management_desc'] = 'ユーザーの作成・更新・権限の管理';
$_lang['user_group_management'] = 'ユーザーグループとロールの管理';
$_lang['user_group_management_desc'] = 'ユーザーグループ・ロール・アクセスポリシーを管理';
$_lang['view_logging'] = '管理操作ログ';
$_lang['view_logging_desc'] = '管理ログを閲覧';
$_lang['view_sysinfo'] = 'システム情報';
$_lang['view_sysinfo_desc'] = 'phpinfo・mysql他サーバー情報の閲覧';
$_lang['wiki'] = 'Wiki';
$_lang['wiki_desc'] = 'Launch the official MODX documentation.';

==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/topmenu.inc.php <==
<?php
/**
 * Top Menu Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 * @author honda http://kogus.org
 */
$_lang['about'] = 'MODXについて';
$_lang['about_desc'] = 'MODX Revolutionに関する情報';
$_lang['access_permissions'] = 'アクセス許可';
$_lang['access_permissions_desc'] = 'リソースとコンテキストへのユーザーアクセス管理';
$_lang['api_docs'] = 'APIドキュメント';
$_lang['api_docs_desc'] = 'MODX Revolution APIドキュメント（英語）を表示';
$_lang['components'] = 'コンポーネント';
$_lang['content_types'] = 'コンテントタイプ';
$_lang['content_types_desc'] = 'リソースのコンテンツタイプを管理。フレンドリーURL設定時に付加される拡張子もここで設定';
$_lang['contexts'] = 'コンテキスト';
$_lang['contexts_desc'] = 'サイトのコンテキストを管理';
$_lang['dashboard'] = 'ダッシュボード';
$_lang['dashboards'] = 'ダッシュボード';
$_lang['dashboards_desc'] = 'ダッシュボードの管理';
$_lang['edit_menu'] = 'アクション';
$_lang['edit_menu_desc'] = '管理画面のアクションとトップメニュー構成の管理';
$_lang['eventlog_viewer'] = 'イベントログ';
$_lang['eventlog_viewer_desc'] = 'エラーログを表示';
$_lang['export_site'] = 'サイトのエクスポート';
$_lang['export_site_desc'] = '現在のウェブサイトを静的なhtmlへエクスポート';
$_lang['flush_access'] = 'アクセス許可をリロード';
$_lang['flush_access_confirm'] = '正しいアクセス許可設定を読み直しますか？注: これは他のユーザーへ影響を与えません';
$_lang['flush_access_desc'] = '一時的にキャッシュされている権限情報を初期化し正しく読み直す';
$_lang['flush_sessions'] = '全セッションを初期化';
$_lang['flush_sessions_confirm'] = '全ユーザーのセッション情報を初期化しますか？自分自身を含めた全ユーザーのセッション情報が初期化されます';
$_lang['flush_sessions_desc'] = '全セッションを初期化し全てのユーザーを強制ログアウト';
$_lang['flush_sessions_err'] = '現在のユーザーセッションを初期化中にエラーが発生しました';
$_lang['flush_sessions_not_supported'] = '現在のアカウントは、ユーザーセッションの初期化権限を持っていません';
$_lang['form_customization'] = '管理画面カスタマイズ機能';
$_lang['form_customization_desc'] = '管理画面のフォームをカスタマイズ。ロール単位で設定可能';
$_lang['forums'] = 'フォーラム';
$_lang['forums_desc'] = '公式MODXフォーラムへアクセス';
$_lang['import_resources'] = 'リソースのインポート';
$_lang['import_resources_desc'] = 'スタティックリソースの一括インポート';
$_lang['import_site'] = 'サイトのインポート';
$_lang['import_site_desc'] = 'HTMLファイルの一括インポート';
$_lang['jira'] = 'バグトラッカー';
$_lang['jira_desc'] = 'MODX バグトラッカーにアクセスし不具合や改善要望を報告';
$_lang['lexicon_management'] = 'レキシコン管理';
$_lang['lexicon_management_desc'] = 'レキシコン(辞書機能・従来の言語ファイルに相当)を管理';
$_lang['logout_desc'] = '管理画面からログアウト';
$_lang['manage_workspaces'] = 'パッケージマネージャー';
$_lang['manage_workspaces_desc'] = '拡張機能やテンプレートを入手・インストール・アンインストール。パッケージ単位で管理';
$_lang['messages'] = 'メッセージ';
$_lang['messages_desc'] = 'メッセージの閲覧と送信';
$_lang['namespaces'] = 'ネームスペース';
$_lang['namespaces_desc'] = 'ネームスペースの定義';
$_lang['new_document'] = 'ドキュメントを新規作成';
$_lang['new_document_desc'] = 'ドキュメントを新規作成';
$_lang['new_resource'] = '新しいリソース';
$_lang['new_resource_desc'] = 'リソースを新規作成';
$_lang['new_static_resource'] = 'スタティックリソースを新規作成';
$_lang['new_static_resource_desc'] = 'スタティックリソース(任意のファイルのクローン)を新規作成';
$_lang['new_symlink'] = 'シムリンクを新規作成';
$_lang['new_symlink_desc'] = 'シムリンク(任意のリソースのクローン)を新規作成';
$_lang['new_weblink'] = 'ウェブリンクを新規作成';
$_lang['new_weblink_desc'] = 'ウェブリンク(任意のURLのエイリアス)を新規作成';
$_lang['policy_management'] = 'アクセスポリシー';
$_lang['policy_management_desc'] = 'セキュリティプロセスのためのポリシー設定';
$_lang['preview'] = 'プレビュー';
$_lang['preview_desc'] = 'サイトを表示(別窓)';
$_lang['profile'] = 'プロフィール';
$_lang['profile_desc'] = '自分自身の個人プロフィールを編集';
$_lang['propertysets'] = 'プロパティセット';
$_lang['propertysets_desc'] = 'プロパティセットと、それらが配置されるエレメントのすべてを管理';
$_lang['refresh_site'] = 'キャッシュをクリア';
$_lang['refresh_site_desc'] = 'キャッシュを初期化。管理画面のレキシコン(言語管理)のキャッシュなども含む';
$_lang['remove_locks'] = 'ロックを解除';
$_lang['remove_locks_desc'] = 'サイト全体の編集ロックを解除';
$_lang['remove_locks_error'] = 'ロックの解除中にエラーが発生しました';
$_lang['reports'] = 'レポート';
$_lang['resource_groups'] = 'リソースグループ';
$_lang['resource_groups_desc'] = 'リソースグループを管理';
$_lang['search'] = '検索';
$_lang['search_desc'] = 'リソースの検索';
$_lang['security'] = '権限管理';
$_lang['site'] = 'サイト';
$_lang['sources'] = 'メディアソース';
$_lang['sources_desc'] = 'メディアソースの管理';
$_lang['support'] = 'サポート';
$_lang['support_desc'] = '';
$_lang['site_schedule'] = '公開状態の一覧';
$_lang['site_schedule_desc'] = '公開および公開終了の予定一覧';
$_lang['system'] = 'システム';
$_lang['system_settings'] = 'システム設定';
$_lang['system_settings_desc'] = 'サイト全体の設定変更';
$_lang['tools'] = 'ツール';
$_lang['user'] = 'ユーザー';
$_lang['user_management'] = 'ユーザー管理';
$_lang['user_management_desc'] = 'ユーザーの作成・更新・権限の管理';
$_lang['user_group_management'] = 'ユーザーグループとロールの管理';
$_lang['user_group_management_desc'] = 'ユーザーグループ・ロール・アクセスポリシーを管理';
$_lang['view_logging'] = '管理操作ログ';
$_lang['view_logging_desc'] = '管理ログを閲覧';
$_lang['view_sysinfo'] = 'システム情報';
$_lang['view_sysinfo_desc'] = 'phpinfo・mysql等のサーバー情報を表示';
$_lang['wiki'] = 'Wiki';
$_lang['wiki_desc'] = 'MODX公式ドキュメント（英語）を表示';
